(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    100636,       3172]
NotebookOptionsPosition[     90514,       2872]
NotebookOutlinePosition[     90854,       2887]
CellTagsIndexPosition[     90811,       2884]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Beast Study: data i/o, functions, and graphics", "Title"],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Dir", "=", " ", "\"\<V6\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SeedRandom", "[", "138", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Histograms`\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<ComputationalGeometry`\>\"", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Helper Functions", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ChopMaxMin", "[", 
   RowBox[{"vals_", ",", " ", "min_", ",", " ", "max_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"vals", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a_", "/;", 
       RowBox[{"a", "<", "min"}]}], "\[Rule]", "min"}], ",", 
     RowBox[{
      RowBox[{"b_", "/;", 
       RowBox[{"b", ">", "max"}]}], "\[Rule]", "max"}]}], "}"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell["Splines", "Subsection"],

Cell[CellGroupData[{

Cell["division by zero is defined a zero ", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BSDivZero", "[", 
   RowBox[{"num_", ",", " ", "den_"}], "]"}], " ", ":=", " ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"PossibleZeroQ", "[", "den", "]"}], ",", "0", ",", 
    RowBox[{"num", "/", "den"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell["\<\
the zero order basis functions (here look for the zero case first, as it is \
more frequent).\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BSBF", "[", 
    RowBox[{"i_Integer", ",", "0", ",", " ", "uvec_", ",", "u_"}], "]"}], " ",
    ":=", " ", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ishift", " ", "=", " ", 
       RowBox[{"i", "+", "1"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Piecewise", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", 
          RowBox[{
           RowBox[{"u", " ", "<", " ", 
            RowBox[{"uvec", "[", 
             RowBox[{"[", "ishift", "]"}], "]"}]}], " ", "||", " ", 
           RowBox[{"u", "\[GreaterEqual]", " ", 
            RowBox[{"uvec", "[", 
             RowBox[{"[", 
              RowBox[{"ishift", "+", "1"}], "]"}], "]"}]}]}]}], "}"}], "}"}], 
       ",", "1"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell["\<\
Recursive (deBoor ) definition for basis function (not most efficient).\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BSBF", "[", 
   RowBox[{"i_Integer", ",", " ", 
    RowBox[{"degree_Integer", "/;", 
     RowBox[{"degree", ">", " ", "0"}]}], ",", "uvec_", " ", ",", "u_"}], 
   "]"}], " ", ":=", "\[IndentingNewLine]", " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"knotlength", "=", 
       RowBox[{"Length", "[", "uvec", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"ishift", "=", " ", 
       RowBox[{"i", "+", "1"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"degree", "+", "1", " ", "+", " ", "ishift"}], ">", " ", 
        "knotlength"}], ",", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"\"\<illegal degree\>\"", ",", " ", 
          RowBox[{"ishift", "+", "1"}], ",", "\"\<>\>\"", ",", " ", 
          RowBox[{"knotlength", " ", "-", " ", "degree"}]}], "]"}], ";", 
        RowBox[{"Throw", "[", "illegalDegree", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"BSDivZero", "[", 
        RowBox[{
         RowBox[{"u", "-", 
          RowBox[{"uvec", "[", 
           RowBox[{"[", "ishift", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"uvec", "[", 
           RowBox[{"[", 
            RowBox[{"ishift", "+", "degree"}], "]"}], "]"}], "-", 
          RowBox[{"uvec", "[", 
           RowBox[{"[", "ishift", "]"}], "]"}]}]}], "]"}], 
       "\[IndentingNewLine]", 
       RowBox[{"BSBF", "[", 
        RowBox[{"i", ",", 
         RowBox[{"degree", "-", "1"}], ",", "uvec", ",", "u"}], "]"}]}], 
      "\[IndentingNewLine]", "+", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"BSDivZero", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"uvec", "[", 
           RowBox[{"[", 
            RowBox[{"ishift", "+", "degree", " ", "+", "1"}], " ", "]"}], 
           "]"}], "-", "u"}], ",", 
         RowBox[{
          RowBox[{"uvec", "[", 
           RowBox[{"[", 
            RowBox[{"ishift", "+", "degree", "+", "1"}], "]"}], "]"}], "-", 
          " ", 
          RowBox[{"uvec", "[", 
           RowBox[{"[", 
            RowBox[{"ishift", "+", "1"}], "]"}], "]"}]}]}], "]"}], 
       "\[IndentingNewLine]", 
       RowBox[{"BSBF", "[", 
        RowBox[{
         RowBox[{"i", "+", " ", "1"}], ",", 
         RowBox[{"degree", "-", "1"}], ",", "uvec", ",", "u"}], "]"}]}]}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell["\<\
Take arbitrary knots and points, wrap on circle, return (number_points + \
degree) wrapped points and (numpoints + 2 degree + 1) \"periodic\" knots.\
\>", "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Wrap", "[", 
   RowBox[{"knots_", ",", " ", "points_", ",", " ", "degree_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"numknots", "=", 
       RowBox[{"Length", "[", "knots", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"numpoints", " ", "=", " ", 
       RowBox[{"Length", "[", "points", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"knotintervals", "=", " ", 
       RowBox[{"Differences", "[", "knots", "]"}]}], ",", 
      "\[IndentingNewLine]", "closedknots", ",", "\[IndentingNewLine]", 
      "closedpoints"}], "\[IndentingNewLine]", "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"closedknots", "[", "1", "]"}], " ", "=", 
      RowBox[{
       RowBox[{"Last", "[", "knots", "]"}], " ", "+", " ", 
       RowBox[{"First", "[", "knotintervals", "]"}]}]}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "these", " ", "are", " ", "the", " ", "additional", " ", "knots"}], 
       ",", " ", 
       RowBox[{
       "to", " ", "be", " ", "joined", " ", "to", " ", "the", " ", 
        "original"}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"closedknots", "[", "n_", "]"}], " ", ":=", 
      RowBox[{
       RowBox[{"closedknots", "[", 
        RowBox[{"n", "-", "1"}], "]"}], " ", "+", " ", 
       RowBox[{"knotintervals", "[", 
        RowBox[{"[", 
         RowBox[{"Mod", "[", 
          RowBox[{"n", ",", 
           RowBox[{"(", 
            RowBox[{"numknots", "-", "1"}], ")"}], ",", "1"}], "]"}], "]"}], 
        "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"closedpoints", " ", "=", " ", 
      RowBox[{
       RowBox[{"NestWhile", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{"#", ",", "#"}], "]"}], "&"}], ",", "points", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Length", "[", "#", "]"}], " ", "\[LessEqual]", " ", 
            RowBox[{"numpoints", "+", "degree"}]}], ")"}], "&"}]}], "]"}], 
       "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", 
         RowBox[{"degree", "+", "numpoints"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"closedpoints", ",", 
       RowBox[{"Join", "[", 
        RowBox[{"knots", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"closedknots", "[", "i", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{
              RowBox[{"2", " ", "degree"}], "+", "1"}]}], "}"}]}], "]"}]}], 
        "]"}]}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BSplinePeriodic", "[", 
    RowBox[{
    "controlpoints_", ",", " ", "knots_", ",", " ", "degree_", ",", "u_"}], 
    "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"closedpoints", ",", "\[IndentingNewLine]", "closedknots"}], 
      "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"closedpoints", ",", "closedknots"}], "}"}], "=", " ", 
       RowBox[{"Wrap", "[", 
        RowBox[{"knots", ",", "controlpoints", ",", "degree"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"BSBF", "[", 
          RowBox[{"i", ",", "degree", ",", "closedknots", ",", "u"}], "]"}], 
         " ", 
         RowBox[{"closedpoints", "[", 
          RowBox[{"[", 
           RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "closedpoints", "]"}], "-", "1"}]}], 
         "}"}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"uniformKnots", "[", "numsides_", "]"}], " ", ":=", " ", 
   RowBox[{"Range", "[", 
    RowBox[{"numsides", "+", "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.423837938082451*^9, 3.423837965861113*^9}}],

Cell[CellGroupData[{

Cell["\<\
add up the sides along the perimeter of a polygon given ITs vertex \
coordinates.\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polygonSides", "[", "iverts_", "]"}], ":=", " ", 
  RowBox[{"Norm", "/@", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"iverts", "[", 
       RowBox[{"[", 
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{"i", "+", "1"}], ",", 
          RowBox[{"Length", "[", "iverts", "]"}], ",", "1"}], "]"}], "]"}], 
       "]"}], " ", "-", " ", 
      RowBox[{"iverts", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "iverts", "]"}]}], "}"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[{
 RowBox[{"polygonSides", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"polygonSides", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "/", "2"}], ",", "0"}], "}"}]}], "}"}], "]"}]}], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Importing and collating data", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rawData", " ", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{
    "\"\</Users/ccarter/People/Neri/Chair/UVdata_NewSurf_01.csv\>\"", ",", 
     " ", "\"\<CSV\>\""}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"rawData", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", 
    RowBox[{"1", ";;", "2"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4239948067962723`*^9, 3.4239948092330227`*^9}, {
  3.423994970019652*^9, 3.423994971402948*^9}, {3.42399507672971*^9, 
  3.423995078153328*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.423995071402467*^9, 3.42399507254482*^9}}],

Cell["Note: check data from file, format may change, wise to check", \
"Subsubsection"],

Cell[CellGroupData[{

Cell["XYZ", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"uvXYZ", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rawData", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", " ", 
          RowBox[{"1", " ", ";;", " ", "2"}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"rawData", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", " ", 
          RowBox[{"3", " ", ";;", " ", "5"}]}], "]"}], "]"}]}], "}"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "rawData", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"uvXYZ", " ", "//", " ", "Short"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dataX", " ", "=", " ", 
   RowBox[{"Sort", "[", " ", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"First", "[", "#", "]"}], ",", " ", 
         RowBox[{"#", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "1"}], "]"}], "]"}]}], "}"}], " ", "&"}], 
      ",", " ", "uvXYZ"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"Length", "[", "dataX", "]"}], "\n", 
 RowBox[{"dataX", " ", "//", " ", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dataY", " ", "=", " ", 
   RowBox[{"Sort", "[", " ", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"First", "[", "#", "]"}], ",", " ", 
         RowBox[{"#", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "2"}], "]"}], "]"}]}], "}"}], " ", "&"}], 
      ",", " ", "uvXYZ"}], "]"}], "]"}]}], ";", " ", 
  RowBox[{"dataZ", " ", "=", " ", 
   RowBox[{"Sort", "[", " ", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"First", "[", "#", "]"}], ",", " ", 
         RowBox[{"#", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "3"}], "]"}], "]"}]}], "}"}], " ", "&"}], 
      ",", " ", "uvXYZ"}], "]"}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Curvature", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"meanCurvatureValuesRaw", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"rawData", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "rawData", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"meanCurvatureValuesRaw", "//", "Short"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"mincuve", ",", "maxcurve"}], "}"}], "=", 
  RowBox[{"Through", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Min", ",", "Max"}], "}"}], "[", "meanCurvatureValuesRaw", "]"}],
    "]"}]}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normals", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"uvnormals", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rawData", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", 
          RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], ",", 
       RowBox[{"rawData", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", 
          RowBox[{"6", ";;", "8"}]}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "rawData", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"uvnormals", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"nxdata", ",", "nydata", ",", "nzdata"}], "}"}], "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Sort", "[", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"First", "[", "#", "]"}], ",", 
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "i"}], "]"}], "]"}]}], "}"}], "&"}], ",", 
        "uvnormals"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data Visualization and Rescaling", "Section"],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"meanCurvatureValuesRaw", ",", 
   RowBox[{"HistogramCategories", "\[Rule]", " ", "50"}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Changed to Absolute Curvature", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Values of curvature limits may change", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"meanCurvatureValuesAbs", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{"Abs", ",", "meanCurvatureValuesRaw"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"meanCurvatureValuesAbs", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"mincurvatureabs", ",", "maxcurvatureabs"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Min", "[", "meanCurvatureValuesAbs", "]"}], ",", 
    RowBox[{"Max", "[", "meanCurvatureValuesAbs", "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"meanCurvatureValuesAbs", ",", 
   RowBox[{"HistogramCategories", "\[Rule]", " ", "50"}]}], "]"}]], "Input"],

Cell["{{{u, v}, H}, ..}", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dataCurvature", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rawData", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", 
          RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"meanCurvatureValuesAbs", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "/", "maxcurvatureabs"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "rawData", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"dataCurvature", "//", "Short"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{
   RowBox[{"Last", "/@", "dataCurvature"}], ",", 
   RowBox[{"HistogramCategories", "\[Rule]", " ", "50"}]}], "]"}]], "Input"],

Cell["{{{u, v}, H}, ..}", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normal angle maps", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"1", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "/", "Pi"}], ")"}], 
     RowBox[{"Abs", "[", 
      RowBox[{"ArcSin", "[", "z", "]"}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Attempts to mirror", "Section"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"mdataX", "=", " ", 
   RowBox[{"(*", 
    RowBox[{"will", " ", "need", " ", "to", " ", "fix"}], "*)"}], 
   RowBox[{"Sort", "@", 
    RowBox[{"Join", "[", 
     RowBox[{"dataX", ",", 
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "10"}], ",", "0"}], "}"}], "+", 
               RowBox[{"dataX", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ",", 
              RowBox[{"dataX", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"Length", "[", "dataX", "]"}]}], "}"}]}], "]"}]}], 
         "]"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[NotEqual]", " ", "5"}],
           ")"}], "&"}]}], "]"}]}], "]"}]}]}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"mdataY", "=", 
   RowBox[{"Sort", "@", 
    RowBox[{"Join", "[", 
     RowBox[{"dataY", ",", 
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "10"}], ",", "0"}], "}"}], "+", 
               RowBox[{"dataY", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ",", 
              RowBox[{"dataY", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"Length", "[", "dataY", "]"}]}], "}"}]}], "]"}]}], 
         "]"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[NotEqual]", " ", "5"}],
           ")"}], "&"}]}], "]"}]}], "]"}]}]}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"mdataZ", "=", 
   RowBox[{"Sort", "@", 
    RowBox[{"Join", "[", 
     RowBox[{"dataZ", ",", 
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "10"}], ",", "0"}], "}"}], "+", 
               RowBox[{"dataZ", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ",", 
              RowBox[{"dataZ", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"Length", "[", "dataZ", "]"}]}], "}"}]}], "]"}]}], 
         "]"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[NotEqual]", " ", "5"}],
           ")"}], "&"}]}], "]"}]}], "]"}]}]}], "*)"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolations", "Section"],

Cell[CellGroupData[{

Cell["Look at interpolation order as improvement in future", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"fx", ",", "fy", ",", "fz"}], "}"}], "=", " ", 
  RowBox[{"Interpolation", "/@", 
   RowBox[{"{", 
    RowBox[{"dataX", ",", "dataY", ",", "dataZ"}], "}"}]}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dfxdu", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"fx", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}]}], ";", " ", 
  RowBox[{"dfxdv", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"fx", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dfydu", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"fy", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}]}], ";", " ", 
  RowBox[{"dfydv", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"fy", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dfzdu", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}]}], ";", " ", 
  RowBox[{"dfzdv", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}]}], ";", 
  "\[IndentingNewLine]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"dfxdu", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "\[Rule]", " ", "4"}], ",", 
    RowBox[{"v", "\[Rule]", " ", "3"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"area", "[", 
   RowBox[{"uval_", ",", "vval_"}], "]"}], " ", ":=", "  ", 
  RowBox[{
   RowBox[{"Norm", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dfxdu", ",", "dfydu", ",", "dfzdu"}], "}"}], "\[Cross]", 
     RowBox[{"{", 
      RowBox[{"dfxdv", ",", "dfydv", ",", "dfzdv"}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Rule]", " ", "uval"}], ",", " ", 
     RowBox[{"v", "\[Rule]", " ", "vval"}]}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"area", "[", 
  RowBox[{"4", ",", "3.1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bounds", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "7"}], "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"mx", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
   RowBox[{"(*", 
    RowBox[{"will", " ", "need", " ", "to", " ", "fix"}], "*)"}], 
   RowBox[{
    RowBox[{
     RowBox[{"Piecewise", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fx", "[", 
           RowBox[{"u", ",", "v"}], "]"}], ",", 
          RowBox[{
          "0", "\[LessEqual]", " ", "u", " ", "\[LessEqual]", " ", "8.5"}]}], 
         "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fx", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"2", "*", "8.5"}], "-", "u"}], ",", "v"}], "]"}], ",", 
          RowBox[{"8.5", " ", "<", " ", "u", " ", "\[LessEqual]", " ", 
           RowBox[{"2", "*", "8.5"}]}]}], "}"}]}], "}"}], "]"}], 
     "\[IndentingNewLine]", 
     RowBox[{"my", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}]}], ":=", 
    RowBox[{
     RowBox[{
      RowBox[{"Piecewise", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"fy", "[", 
            RowBox[{"u", ",", "v"}], "]"}], ",", 
           RowBox[{
           "0", "\[LessEqual]", " ", "u", " ", "\[LessEqual]", " ", "8.5"}]}],
           "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"2", 
             StyleBox["*", "Code"], "50.4042"}], " ", "-", 
            RowBox[{"fy", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"2", "*", "8.5"}], "-", "u"}], ",", "v"}], "]"}]}], 
           ",", 
           RowBox[{"8.5", " ", "<", " ", "u", " ", "\[LessEqual]", " ", 
            RowBox[{"2", "*", "8.5"}]}]}], "}"}]}], "}"}], "]"}], 
      "\[IndentingNewLine]", 
      RowBox[{"mz", "[", 
       RowBox[{"u_", ",", "v_"}], "]"}]}], ":=", 
     RowBox[{"Piecewise", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fz", "[", 
           RowBox[{"u", ",", "v"}], "]"}], ",", 
          RowBox[{
          "0", "\[LessEqual]", " ", "u", " ", "\[LessEqual]", " ", "8.5"}]}], 
         "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fz", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"2", "*", "8.5"}], "-", "u"}], ",", "v"}], "]"}], ",", 
          RowBox[{"8.5", " ", "<", " ", "u", " ", "\[LessEqual]", " ", 
           RowBox[{"2", "*", "8.5"}]}]}], "}"}]}], "}"}], "]"}]}]}]}], 
  "\[IndentingNewLine]", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"mfx", ",", "mfy", ",", "mfz"}], "}"}], "=", " ", 
   RowBox[{"Interpolation", "/@", 
    RowBox[{"{", 
     RowBox[{"mdataX", ",", "mdataY", ",", "mdataZ"}], "}"}]}]}], 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"Curvature", "=", " ", 
  RowBox[{"Interpolation", "[", "dataCurvature", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"nx", ",", "ny", ",", "nz"}], "}"}], "=", " ", 
  RowBox[{"Interpolation", "/@", 
   RowBox[{"{", 
    RowBox[{"nxdata", ",", "nydata", ",", "nzdata"}], "}"}]}]}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3D representations of interpolations", "Section"],

Cell[CellGroupData[{

Cell["surface with uv mesh", "Subsection"],

Cell[BoxData[
 RowBox[{"p", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fx", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", ",", " ", 
      RowBox[{"fy", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"fz", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", "11"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", "7"}], "}"}], ",", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"FaceForm", "[", 
        RowBox[{"Orange", ",", "Yellow"}], "]"}]}], ","}], "*)"}], 
    RowBox[{"Mesh", "\[Rule]", " ", "True"}], ",", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"RegionFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#3", " ", "#2"}], " ", "-", " ", 
               RowBox[{"#1", " ", 
                RowBox[{"#4", "/", "8"}]}]}], ")"}], "/", "350"}], "]"}], "^",
            "2"}], "<", ".5"}], "  ", "&"}], ")"}]}], ","}], "*)"}], 
    RowBox[{"MeshShading", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"RGBColor", "@@", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.1", ",", "0.2", ",", "1"}], "}"}], 
            RowBox[{"RandomReal", "[", 
             RowBox[{
              RowBox[{"{", "}"}], ",", "3"}], "]"}]}], ")"}]}], ",", 
         RowBox[{"{", "10", "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Glow", "[", 
          RowBox[{"RGBColor", "@@", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0.1", ",", "0.5", ",", "1"}], "}"}], 
             RowBox[{"RandomReal", "[", 
              RowBox[{
               RowBox[{"{", "}"}], ",", "3"}], "]"}]}], ")"}]}], "]"}], ",", 
         RowBox[{"{", "10", "}"}]}], "]"}]}], "}"}]}], ",", 
    RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"fX", ",", "fY", ",", "fZ"}], "}"}]}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", " ", "Automatic"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", " ", "Full"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/testHalf_mod.dxf\>\"", ",", "p", 
    ",", "\"\<DXF\>\""}], "]"}], "*)"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["curvature", "Subsection"],

Cell[BoxData[
 RowBox[{"pH", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fx", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", ",", " ", 
      RowBox[{"fy", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"fz", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", "11"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", "7"}], "}"}], ",", 
    RowBox[{"Mesh", "\[Rule]", " ", "True"}], ",", 
    RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}], ",", 
    RowBox[{"ColorFunction", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z", ",", "u", ",", "v"}], "}"}], ",", 
       RowBox[{"Hue", "[", 
        RowBox[{"0.75", 
         RowBox[{"Curvature", "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}]}], ",", 
    RowBox[{"ColorFunctionScaling", "\[Rule]", " ", "False"}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"fX", ",", "fY", ",", "fZ"}], "}"}]}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["angle from vertical", "Subsection"],

Cell[BoxData[
 RowBox[{"pNorm", "=", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fx", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", ",", " ", 
      RowBox[{"fy", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"fz", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", "11"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", "7"}], "}"}], ",", 
    RowBox[{"Mesh", "\[Rule]", " ", "True"}], ",", 
    RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}], ",", 
    RowBox[{"ColorFunction", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z", ",", "u", ",", "v"}], "}"}], ",", 
       RowBox[{"Hue", "[", 
        RowBox[{"0.75", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "/", "Pi"}], ")"}], 
            RowBox[{"Abs", "[", 
             RowBox[{"ArcSin", "[", 
              RowBox[{"nz", "[", 
               RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}]}]}], ")"}]}], 
        "]"}]}], "]"}]}], ",", 
    RowBox[{"ColorFunctionScaling", "\[Rule]", " ", "False"}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"fX", ",", "fY", ",", "fZ"}], "}"}]}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "]"}]}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Voronoi cells", "Section"],

Cell[CellGroupData[{

Cell["Uniform Voronoi", "Subsection"],

Cell[BoxData[
 RowBox[{"bounds", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"11", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"11", ",", "7"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "7"}], "}"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"llx", ",", "lly"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"lrx", ",", "lry"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"urx", ",", "ury"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"ulx", ",", "uly"}], "}"}]}], "}"}], "=", "bounds"}]], "Input",
 CellChangeTimes->{{3.424016244517385*^9, 3.4240162452549343`*^9}, {
  3.424019422022108*^9, 3.424019481212858*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data2D", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"bounds", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"bounds", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"bounds", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"bounds", "[", 
           RowBox[{"[", 
            RowBox[{"4", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", "24", "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Shallow", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6"}], "}"}]}], "]"}], "&"}], ")"}], "[", 
  RowBox[{"delval", "=", 
   RowBox[{"DelaunayTriangulation", "[", "data2D", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"vorvert", ",", "vorval"}], "}"}], "=", 
   RowBox[{"VoronoiDiagram", "[", "data2D", "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"diagvert1", ",", "diagval1"}], "}"}], "=", 
    RowBox[{"BoundedDiagram", "[", 
     RowBox[{"bounds", ",", "data2D"}], "]"}]}], ";"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{"diagvert1", "//", "Short"}], "\[IndentingNewLine]", 
 RowBox[{"diagval1", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{"DiagramPlot", "[", 
  RowBox[{"data2D", ",", "diagvert1", ",", "diagval1"}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Curvature correlated Voronoi", "Subsection"],

Cell[CellGroupData[{

Cell["the set of u-v patches to be weighted", "Subsubsection"],

Cell[BoxData["bounds"], "Input",
 CellChangeTimes->{{3.4240193909929323`*^9, 3.42401939190687*^9}}],

Cell[BoxData[{
 RowBox[{"patchSize", "=", "  ", ".05"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"patches", " ", "=", 
   RowBox[{"Flatten", "[", " ", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v"}], "}"}], "+", " ", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1"}], "}"}], 
         RowBox[{"patchSize", "/", "2"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"u", ",", "llx", ",", 
         RowBox[{"lrx", "-", "patchSize"}], ",", "patchSize"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", "lly", ",", 
         RowBox[{"uly", "-", "patchSize"}], ",", "patchSize"}], "}"}]}], 
      "]"}], ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"patches", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"patchAreas", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"area", "@@", "#"}], ",", "#"}], "}"}], "&"}], ")"}], "/@", 
    " ", "patches"}]}], ";", 
  RowBox[{"patchAreas", "//", "Short"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"Map", "[", 
   RowBox[{"First", ",", "patchAreas"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"minarea", ",", "maxarea"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Min", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"First", ",", "patchAreas"}], "]"}], "]"}], ",", 
    RowBox[{"Max", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"First", ",", "patchAreas"}], "]"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scaledpatchAreas", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"First", "[", "#", "]"}], "/", "maxarea"}], ",", 
        RowBox[{"Last", "[", "#", "]"}]}], "}"}], "&"}], ",", "patchAreas"}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Count", "[", 
  RowBox[{"scaledpatchAreas", ",", 
   RowBox[{"{", 
    RowBox[{"0.0", ",", "___"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"Map", "[", 
   RowBox[{"First", ",", "scaledpatchAreas"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"minarea", ",", "maxarea"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Min", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"First", ",", "scaledpatchAreas"}], "]"}], "]"}], ",", 
    RowBox[{"Max", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"First", ",", "scaledpatchAreas"}], "]"}], "]"}]}], 
   "}"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
interpolate the curvature at each corner (may wish to move this to center) \
rescale and chop according to method of curvature data extraction\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"patchCurvatures", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"Curvature", "@@", "#"}], "]"}], ",", "#"}], "}"}], "&"}], 
     ")"}], "/@", " ", "patches"}]}], ";", 
  RowBox[{"patchCurvatures", "//", "Short"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"Map", "[", 
   RowBox[{"First", ",", "patchCurvatures"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"mincurv", ",", "maxcurv"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Min", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"First", ",", "patchCurvatures"}], "]"}], "]"}], ",", 
    RowBox[{"Max", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"First", ",", "patchCurvatures"}], "]"}], "]"}]}], 
   "}"}]}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Arbitrary scaling for patch choice: area*(1+8 Abs[curvature]^2)\
\>", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numpatches", "=", " ", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"patchSelection", " ", "=", " ", 
   RowBox[{"RandomChoice", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{"First", ",", "scaledpatchAreas"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", " ", 
         RowBox[{"8", "*", " ", 
          RowBox[{
           RowBox[{"Map", "[", 
            RowBox[{"First", ",", "patchCurvatures"}], "]"}], "^", "2"}]}]}], 
        ")"}]}], "\[Rule]", " ", 
      RowBox[{"Evaluate", "@", 
       RowBox[{"Range", "[", 
        RowBox[{"Length", "[", "patchCurvatures", "]"}], "]"}]}]}], ",", 
     "numpatches"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"patchSelection", "//", "Short"}]}], "Input"],

Cell[CellGroupData[{

Cell["Create 2D voronoi data from patch selection ", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vordataCurv", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"patches", "[", 
       RowBox[{"[", 
        RowBox[{"patchSelection", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], "+", " ", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], 
        RowBox[{"patchSize", "/", "2"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "patchSelection", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"data2D", "//", "Short"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bounded voronoi computation", "Subsubsection"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Timing", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"vorvertsCurv", ",", "vorvalsCurv"}], "}"}], "=", 
     RowBox[{"BoundedDiagram", "[", 
      RowBox[{"bounds", ",", "vordataCurv"}], "]"}]}], ";"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.424018684703156*^9, 3.4240186915725307`*^9}, {
  3.4240190571588697`*^9, 3.424019062773075*^9}, {3.4240191274967117`*^9, 
  3.4240191737895603`*^9}, {3.424019733647016*^9, 3.424019734532971*^9}}],

Cell[BoxData[{
 RowBox[{"vorvertsCurv", "//", "Short"}], "\[IndentingNewLine]", 
 RowBox[{"vorvalsCurv", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{"DiagramPlot", "[", 
  RowBox[{"vordataCurv", ",", "vorvertsCurv", ",", "vorvalsCurv"}], 
  "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell["Macroscale Voronoi for buffers", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Use nearest on higher scale poisson distribution to get voronoi generating \
function.\
\>", "Subsection",
 CellChangeTimes->{{3.4238435356172*^9, 3.423843570980907*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"seconddata2D", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"bounds", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"bounds", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"bounds", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"bounds", "[", 
           RowBox[{"[", 
            RowBox[{"4", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", "85", "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"nf", "=", 
  RowBox[{"Nearest", "[", "seconddata2D", "]"}]}]], "Input"],

Cell[BoxData[" "], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data Precalculations", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"materialChoices", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"GrayLevel", "[", "0.8", "]"}], ",", 
     RowBox[{"GrayLevel", "[", "0.6", "]"}], ",", 
     RowBox[{"GrayLevel", "[", "0.2", "]"}], ",", 
     RowBox[{"GrayLevel", "[", "0", "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"materialIndices", "=", 
   RowBox[{"Range", "[", 
    RowBox[{"Length", "[", "materialChoices", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"materialMembers", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Length", "[", "materialChoices", "]"}], "}"}]}], 
   "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"colorOfMaterial", "[", "materialindex_", "]"}], " ", ":=", " ", 
   RowBox[{"materialChoices", "[", 
    RowBox[{"[", "materialindex", "]"}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[CellGroupData[{

Cell["Gradient choice", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"LoopMaterial", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"matchoice", "[", 
   RowBox[{"i_", ",", "localnorm_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "angleweight", ",", "nz", ",", "weights", ",", "thecolor", ",", 
      "theindex"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"Print", "[", "localnorm", "]"}], ";"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"nz", "=", " ", 
      RowBox[{"localnorm", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"weights", "=", 
      RowBox[{"Table", "[", " ", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"Abs", "[", "nz", "]"}], "^", "2"}], " ", "+", " ", 
         RowBox[{"2", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", "nz", "]"}], "^", "2"}], "-", "0.5"}], " ", 
           ")"}], "xtab"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"xtab", ",", "0", ",", "1", ",", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Length", "[", "materialChoices", "]"}], "-", "1"}], 
            ")"}]}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<nz \>\"", ",", "nz", ",", " ", "\"\<\\t wts\>\"", ",", 
         "weights"}], "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"theindex", "=", 
      RowBox[{"RandomChoice", "[", 
       RowBox[{"weights", "\[Rule]", " ", "materialIndices"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{
       RowBox[{"materialMembers", "[", 
        RowBox[{"[", "theindex", "]"}], "]"}], ",", "i"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"LoopMaterial", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "=", " ", 
      RowBox[{"materialChoices", "[", 
       RowBox[{"[", "theindex", "]"}], "]"}]}], ";"}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input"],

Cell[BoxData[""], "Input"],

Cell[BoxData[
 RowBox[{"Transpose", "[", 
  RowBox[{"{", 
   RowBox[{"vorvalsCurv", "[", 
    RowBox[{"[", 
     RowBox[{"123", ",", "2"}], "]"}], "]"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"vorvertsCurv", "[", 
  RowBox[{"[", "158", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Extract", "[", 
  RowBox[{"vorvertsCurv", ",", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"vorvalsCurv", "[", 
      RowBox[{"[", 
       RowBox[{"123", ",", "2"}], "]"}], "]"}], "}"}], "]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"loopInPlaneCenter", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Mean", "[", 
       RowBox[{"Extract", "[", 
        RowBox[{"vorvertsCurv", ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"vorvalsCurv", "[", 
            RowBox[{"[", 
             RowBox[{"#", ",", "2"}], "]"}], "]"}], "}"}], "]"}]}], "]"}], 
       "]"}], "&"}], ",", 
     RowBox[{"Range", "[", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"loopInPlaneCenter", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loopNormal", "=", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Normalize", "[", 
        RowBox[{"Through", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"nx", ",", "ny", ",", "nz"}], "}"}], "@@", "#"}], "]"}], 
        "]"}], "&"}], ",", "loopInPlaneCenter"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"loopNormal", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"matchoice", "[", 
  RowBox[{"1", ",", 
   RowBox[{"loopNormal", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"materialMembers", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Length", "[", "materialChoices", "]"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"matchoice", "[", 
     RowBox[{"i", ",", 
      RowBox[{"loopNormal", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "loopNormal", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"materialMembers", ",", "12"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"LoopMaterial", ",", "12"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Length", ",", "materialMembers"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"BarChart", "[", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{"Length", ",", "materialMembers"}], "]"}], ",", 
   RowBox[{"FrequencyData", "\[Rule]", " ", "True"}], ",", 
   RowBox[{"BarStyle", "\[Rule]", " ", "materialChoices"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"getLoopVertices", "[", 
   RowBox[{"i_", ",", " ", "verts_", ",", "vors_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ivor", ",", "itemp"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ivor", "=", " ", 
      RowBox[{"vors", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"verts", "[", 
        RowBox[{"[", 
         RowBox[{"ivor", "[", 
          RowBox[{"[", "itemp", "]"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"itemp", ",", "1", ",", 
         RowBox[{"Length", "[", "ivor", "]"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"loopVertices", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"getLoopVertices", "[", 
        RowBox[{"i", ",", "vorvertsCurv", ",", "vorvalsCurv"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"loopVertices", "//", "Short"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"getBufferSize", "[", 
   RowBox[{"i_", ",", "nearestfunction_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"closest", ",", "secondclosest", ",", "frac"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"closest", ",", "secondclosest"}], "}"}], "=", 
      RowBox[{"nearestfunction", "[", 
       RowBox[{
        RowBox[{"loopInPlaneCenter", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", "2"}], "]"}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"frac", "=", 
      RowBox[{
       RowBox[{"Norm", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"loopInPlaneCenter", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "-", "closest"}], ")"}], ".", 
         RowBox[{"(", 
          RowBox[{"secondclosest", "-", "closest"}], ")"}]}], "]"}], "/", 
       RowBox[{"Norm", "[", 
        RowBox[{"(", 
         RowBox[{"secondclosest", "-", "closest"}], ")"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"scaling", " ", "bsize", " ", "with", " ", 
        RowBox[{"frac", ":", " ", 
         RowBox[{"fatter", " ", "in", " ", "middle"}]}]}], ",", " ", 
       RowBox[{"parameters", " ", "somewhat", " ", "arbitrary"}]}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"0.33", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "12"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"frac", "-", "0.5"}], ")"}], "^", "2"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"loopBuffers", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getBufferSize", "[", 
      RowBox[{"i", ",", "nf"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"loopBuffers", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"getShrunkVerts", "[", "i_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"bsize", ",", "meanpos"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"bsize", "=", 
      RowBox[{"loopBuffers", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"meanpos", "=", " ", 
      RowBox[{"loopInPlaneCenter", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"meanpos", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "bsize"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"#", "-", "meanpos"}], ")"}]}]}], ")"}], "&"}], ",", 
       RowBox[{"loopVertices", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"loopShrunkVerts", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getShrunkVerts", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"splineOrder", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"getSplineFunction", "[", "i_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"knots", ",", "shrunkverts", ",", "meanpos", ",", "bsize"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"bsize", "=", 
      RowBox[{"loopBuffers", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"meanpos", "=", " ", 
      RowBox[{"loopInPlaneCenter", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"shrunkverts", "=", 
      RowBox[{"loopShrunkVerts", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"knots", "=", " ", 
      RowBox[{"Range", "[", 
       RowBox[{"Length", "[", 
        RowBox[{"loopVertices", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"BSplinePeriodic", "[", 
      RowBox[{"shrunkverts", ",", "knots", ",", "splineOrder", ",", "s"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random spline order", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"loopSplineOrder", "=", 
   RowBox[{"Table", "[", " ", 
    RowBox[{
     RowBox[{"RandomChoice", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"6", ",", "2", ",", "1"}], "}"}], "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "4"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loopSplineOrder", "=", 
    RowBox[{"Table", "[", " ", 
     RowBox[{"2", ",", 
      RowBox[{"{", 
       RowBox[{"Length", "[", "vorvalsCurv", "]"}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"fill", " ", "and", " ", "replace"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"getSplineOrder", "[", 
    RowBox[{"i_", ",", "localnorm_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nz", ",", "weights", ",", "theindex"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Print", "[", "localnorm", "]"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"nz", "=", " ", 
       RowBox[{"localnorm", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"weights", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", " ", 
           RowBox[{"1", "-", 
            RowBox[{"Abs", "[", "nz", "]"}], "+", " ", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Abs", "[", "nz", "]"}], "-", "0.5"}], " ", ")"}], 
             "xtab"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"Abs", "[", "nz", "]"}]}], ")"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"xtab", ",", "0", ",", ".5", ",", ".5"}], "}"}]}], "]"}]}], 
      ";", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<nz \>\"", ",", "nz", ",", " ", "\"\<\\t wts\>\"", ",", 
          "weights"}], "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"theindex", "=", 
       RowBox[{"RandomChoice", "[", 
        RowBox[{"weights", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"3", ",", "2"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"loopSplineOrder", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", " ", "theindex"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"getSplineOrder", "[", 
     RowBox[{"i", ",", 
      RowBox[{"loopNormal", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "loopNormal", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"loopSplineOrder", ",", "12"}], 
  "]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", "loopSplineOrder", "]"}], "//", "N"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"getSplineFunction", "[", "i_", "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"knots", ",", "shrunkverts", ",", "meanpos", ",", "bsize"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"bsize", "=", 
        RowBox[{"loopBuffers", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"meanpos", "=", " ", 
        RowBox[{"loopInPlaneCenter", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"shrunkverts", "=", 
        RowBox[{"loopShrunkVerts", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"knots", "=", " ", 
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", 
          RowBox[{"loopVertices", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"BSplinePeriodic", "[", 
        RowBox[{"shrunkverts", ",", "knots", ",", 
         RowBox[{"loopSplineOrder", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", "s"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"loopSpline", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getSplineFunction", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[""], "Input"],

Cell[BoxData[
 RowBox[{"loopVertices", "[", 
  RowBox[{"[", "12", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"loopShrunkVerts", "[", 
  RowBox[{"[", "12", "]"}], "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numSegments", "=", " ", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"getSplineVertsInPlane", "[", "i_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "tp", ",", "tn", ",", "knots", ",", "iter", ",", "numsides", ",", 
      "splineOrd"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"numsides", "=", 
      RowBox[{"Length", "[", 
       RowBox[{"loopVertices", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"knots", "=", 
      RowBox[{"Range", "[", "numsides", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"splineOrd", "=", 
      RowBox[{"loopSplineOrder", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"tp", ",", "tn"}], "}"}], "=", " ", 
      RowBox[{"Wrap", "[", 
       RowBox[{"knots", ",", 
        RowBox[{"loopShrunkVerts", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", "splineOrd"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"loopSpline", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "/.", 
        RowBox[{"s", "\[Rule]", " ", "iter"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"iter", ",", 
         RowBox[{"tn", "[", 
          RowBox[{"[", 
           RowBox[{"splineOrd", "+", "1"}], "]"}], "]"}], ",", 
         RowBox[{"tn", "[", 
          RowBox[{"[", 
           RowBox[{"splineOrd", "+", "1", "+", "numsides"}], "]"}], "]"}], 
         ",", 
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{
            RowBox[{"tn", "[", 
             RowBox[{"[", 
              RowBox[{"splineOrd", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"tn", "[", 
             RowBox[{"[", 
              RowBox[{"splineOrd", "+", "1", "+", "numsides"}], "]"}], 
             "]"}]}], "]"}], "/", "numSegments"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"iloop2D", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{
    RowBox[{"Dynamic", "[", "iloop2D", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"splineVertsInPlane", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getSplineVertsInPlane", "[", "iloop2D", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"iloop2D", ",", "1", ",", 
       RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"iloop3D", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{
    RowBox[{"Dynamic", "[", "iloop3D", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"loopSplineVertices3D", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Map", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Through", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"fx", ",", "fy", ",", "fz"}], "}"}], "@@", "#"}], "]"}], 
        "&"}], ",", 
       RowBox[{"splineVertsInPlane", "[", 
        RowBox[{"[", "iloop3D", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"iloop3D", ",", "1", ",", 
       RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"loopSplineVertices3D", ",", "36"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"loopSplineVerts3D", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"loopSplineVertices3D", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "vorvalsCurve", "]"}]}], "}"}]}], "]"}]}], 
   ";"}], "*)"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Projection of u-v plane Voronoi loops onto 3D interpolated surface\
\>", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeLoop3D", "[", "i_", "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"LoopMaterial", "[", 
     RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
    RowBox[{"Polygon", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"loopSplineVertices3D", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"First", "[", 
         RowBox[{"loopSplineVertices3D", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "]"}], "}"}]}], "]"}], "]"}]}], 
   "}"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3D Graphics Examples", "Section"],

Cell[BoxData[
 RowBox[{"MakeLoop3D", "[", "12", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{
   RowBox[{"MakeLoop3D", "[", "5", "]"}], ",", 
   RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"iloop", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{
    RowBox[{"Dynamic", "[", "iloop", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.424017831618177*^9, 3.424017863340287*^9}, {
   3.4240179085652647`*^9, 3.424017949388892*^9}, 3.424018164102714*^9, {
   3.4240915508954763`*^9, 3.424091563092188*^9}}],

Cell[BoxData[
 RowBox[{"g3d", "=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"MakeLoop3D", "[", "iloop", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"iloop", ",", "1", ",", 
        RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", " ", "Full"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"g3d", ",", 
    RowBox[{"Lighting", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<Ambient\>\"", ",", " ", "White"}], "}"}], "}"}]}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
    "<>", "\"\</allmaterials.eps\>\""}], ",", "tmp", ",", "\"\<EPS\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
    "<>", "\"\</allmaterials.dxf\>\""}], ",", "tmp", ",", "\"\<DXF\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphicsmat", "[", "i_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"graphicsmat", "[", "i", "]"}], "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MakeLoop3D", "[", "#", "]"}], "&"}], ",", " ", 
       RowBox[{"materialMembers", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", " ", "Full"}], ",", 
     RowBox[{"Lighting", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<Ambient\>\"", ",", " ", "White"}], "}"}], "}"}]}]}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"graphicsmat", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"graphicsmat", "[", "2", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"graphicsmat", "[", "3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"graphicsmat", "[", "4", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Writing data out", "Section"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"WriteLoop3D", "[", "i_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
       "directory", "=", " ", 
        "\"\</Users/ccarter/People/Neri/Chair/Data/\>\""}], ",", "filename"}],
       "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"filename", "=", " ", 
       RowBox[{"StringJoin", "[", 
        RowBox[{"directory", ",", "\"\<loop_\>\"", ",", 
         RowBox[{"ToString", "[", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"i", ",", "6", ",", 
            RowBox[{"NumberPadding", "\[Rule]", " ", 
             RowBox[{"{", 
              RowBox[{"\"\<0\>\"", ",", "\"\<\>\""}], "}"}]}]}], "]"}], "]"}],
          ",", "\"\<dxf\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Export", "[", 
       RowBox[{"filename", ",", 
        RowBox[{"Graphics3D", "[", 
         RowBox[{
          RowBox[{"MakeLoop3D", "[", "i", "]"}], ",", 
          RowBox[{"Lighting", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"{", 
             RowBox[{"\"\<Ambient\>\"", ",", " ", "White"}], "}"}], "}"}]}]}],
          "]"}], ",", "\"\<DXF\>\""}], "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
    "<>", "\"\</material_1.dxf\>\""}], ",", 
   RowBox[{"graphicsmat", "[", "1", "]"}], ",", "\"\<DXF\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
    "<>", "\"\</material_2.dxf\>\""}], ",", 
   RowBox[{"graphicsmat", "[", "2", "]"}], ",", "\"\<DXF\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
    "<>", "\"\</material_3.dxf\>\""}], ",", 
   RowBox[{"graphicsmat", "[", "3", "]"}], ",", "\"\<DXF\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
    "<>", "\"\</material_4.dxf\>\""}], ",", 
   RowBox[{"graphicsmat", "[", "4", "]"}], ",", "\"\<DXF\>\""}], 
  "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bumps", "Section",
 CellChangeTimes->{{3.4238436661066*^9, 3.423843668589039*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pushout", "[", 
   RowBox[{"theverts_", ",", " ", "distance_", ",", " ", 
    RowBox[{"{", 
     RowBox[{"nx_", ",", " ", "ny_", ",", " ", "nz_"}], "}"}]}], "]"}], ":=", 
  " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"theverts", "[", 
      RowBox[{"[", "i", "]"}], "]"}], " ", "+", " ", 
     RowBox[{"distance", "*", 
      RowBox[{"{", 
       RowBox[{"nx", ",", "ny", ",", "nz"}], "}"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "theverts", "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell["sharp", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bumpProfile", "[", 
   RowBox[{
   "verts3D_", ",", " ", "frac_", ",", " ", "meanposition_", ",", " ", 
    "locnorm_", ",", " ", "approxradius_"}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"pushout", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"meanposition", " ", "+", " ", 
         RowBox[{"frac", 
          RowBox[{"(", 
           RowBox[{"#", "-", "meanposition"}], ")"}]}]}], ")"}], "&"}], ",", 
      "verts3D"}], "]"}], ",", 
    RowBox[{"(*", 
     RowBox[{"??", "?"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"frac", " ", "approxradius"}], " ", "-", " ", 
      RowBox[{"Sqrt", "[", "2", "]"}]}], ")"}], ",", "\[IndentingNewLine]", 
    "locnorm"}], "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["soft", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bumpProfile", "[", 
   RowBox[{
   "verts3D_", ",", " ", "frac_", ",", " ", "meanposition_", ",", " ", 
    "locnorm_", ",", " ", "approxradius_"}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"pushout", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"meanposition", " ", "+", " ", 
         RowBox[{"frac", 
          RowBox[{"(", 
           RowBox[{"#", "-", "meanposition"}], ")"}]}]}], ")"}], "&"}], ",", 
      "verts3D"}], "]"}], ",", 
    RowBox[{"(*", 
     RowBox[{"??", "?"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sqrt", "[", "2", "]"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "2"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"frac", " ", "approxradius"}], " ", ")"}], "^", "4"}]}], 
         "]"}], "-", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "2"}], 
          RowBox[{
           RowBox[{"(", " ", "approxradius", " ", ")"}], "^", "4"}]}], 
         "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "2"}], 
          RowBox[{
           RowBox[{"(", " ", "approxradius", " ", ")"}], "^", "4"}]}], 
         "]"}]}], ")"}]}]}], ",", "\[IndentingNewLine]", "locnorm"}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell["\<\
Need to add a final cone point for lofting.  Shape is still arbitrary\
\>", "Subsubsection",
 CellChangeTimes->{{3.423843704462714*^9, 3.423843723317133*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeBump", "[", "i_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
     "output", ",", "meaninplane", ",", "meanpos", ",", "approxrad", ",", 
      "loopverts"}], "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]",
     
    RowBox[{
     RowBox[{"output", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FaceForm", "[", "]"}], ",", 
        RowBox[{"EdgeForm", "[", 
         RowBox[{"LoopMaterial", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
        RowBox[{"MakeLoop3D", "[", "i", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"meaninplane", "=", 
      RowBox[{"Mean", "[", 
       RowBox[{"splineVertsInPlane", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"approxrad", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Norm", "[", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"#", "-", "meaninplane"}], ")"}], "&"}], ",", 
          RowBox[{"splineVertsInPlane", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"meanpos", "=", " ", 
      RowBox[{"Mean", "[", 
       RowBox[{"loopSplineVertices3D", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Return", "[", "output", "]"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"AppendTo", "[", 
        RowBox[{"output", ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"EdgeForm", "[", 
            RowBox[{"Hue", "[", 
             RowBox[{".75", " ", "ifrac"}], "]"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Polygon", "[", 
            RowBox[{"bumpProfile", "[", 
             RowBox[{
              RowBox[{"loopSplineVertices3D", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "ifrac", ",", "meanpos", 
              ",", 
              RowBox[{"loopNormal", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "approxrad"}], "]"}], 
            "]"}]}], "\[IndentingNewLine]", "}"}]}], "\[IndentingNewLine]", 
        "]"}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"ifrac", ",", 
         RowBox[{"{", 
          RowBox[{".9", ",", ".6", ",", ".3", ",", ".1"}], "}"}]}], "}"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"output", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RGBColor", "[", 
          RowBox[{"1", ",", ".2", ",", "0"}], "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"meanpos", "-", " ", 
           RowBox[{
            RowBox[{"Sqrt", "[", "2", "]"}], " ", 
            RowBox[{"loopNormal", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}]}], "}"}]}], "]"}], ";",
      "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeBump", "[", 
   RowBox[{"i_", ",", " ", "frac_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
     "output", ",", "meaninplane", ",", "meanpos", ",", "approxrad", ",", 
      "loopverts"}], "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"meanpos", "=", " ", 
      RowBox[{"Mean", "[", 
       RowBox[{"loopSplineVertices3D", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"meaninplane", "=", 
      RowBox[{"Mean", "[", 
       RowBox[{"splineVertsInPlane", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"approxrad", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Norm", "[", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"#", "-", "meaninplane"}], ")"}], "&"}], ",", 
          RowBox[{"splineVertsInPlane", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"frac", "\[Equal]", "1"}], " ", "||", " ", 
        RowBox[{"frac", "\[Equal]", "1.0"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"output", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FaceForm", "[", "]"}], ",", 
          RowBox[{"EdgeForm", "[", 
           RowBox[{"LoopMaterial", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
          RowBox[{"MakeLoop3D", "[", "i", "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"frac", "\[Equal]", "0"}], " ", "||", " ", 
        RowBox[{"frac", "\[Equal]", " ", "0.0"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"output", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"RGBColor", "[", 
           RowBox[{"1", ",", ".2", ",", "0"}], "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"Mean", "[", 
            RowBox[{"bumpProfile", "[", 
             RowBox[{
              RowBox[{"loopSplineVertices3D", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "0.025", ",", "meanpos", 
              ",", 
              RowBox[{"loopNormal", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "approxrad"}], "]"}], 
            "]"}], "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", "True", ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"output", "=", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FaceForm", "[", "]"}], ",", 
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Hue", "[", 
            RowBox[{".75", " ", "frac"}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Polygon", "[", 
           RowBox[{"bumpProfile", "[", 
            RowBox[{
             RowBox[{"loopSplineVertices3D", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "frac", ",", "meanpos", 
             ",", 
             RowBox[{"loopNormal", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "approxrad"}], "]"}], 
           "]"}]}], "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{"MakeBump", "[", "23", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"iloop2", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{
    RowBox[{"Dynamic", "[", "iloop2", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.424017831618177*^9, 3.424017863340287*^9}, {
   3.4240179085652647`*^9, 3.424017949388892*^9}, 3.424018164102714*^9, {
   3.4240915508954763`*^9, 3.424091563092188*^9}, {3.424093934183593*^9, 
   3.4240939382227077`*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "g3dBumpSet", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"g3dBumpSet", "[", "frac_", "]"}], ":=", 
   RowBox[{
    RowBox[{"g3dBumpSet", "[", "frac", "]"}], "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"MakeBump", "[", 
        RowBox[{"iloop2", ",", "frac"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"iloop2", ",", "1", ",", 
         RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"g3dBumpSet", "[", "1", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"g3dBumpSet", "[", "1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"g3dBumpSet", "[", ".9", "]"}], "\[IndentingNewLine]", 
 RowBox[{"g3dBumpSet", "[", ".6", "]"}], "\[IndentingNewLine]", 
 RowBox[{"g3dBumpSet", "[", ".3", "]"}], "\[IndentingNewLine]", 
 RowBox[{"g3dBumpSet", "[", ".1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"g3dBumpSet", "[", "0.0", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"allBumps", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"g3dBumpSet", "[", "j", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", ".9", ",", ".6", ",", ".3", ",", ".1", ",", "0"}], 
        "}"}]}], "}"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
    "<>", "\"\</allmaterials_allbumps.eps\>\""}], ",", "allBumps", ",", 
   "\"\<EPS\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
    "<>", "\"\</allmaterials_allbumps.dxf\>\""}], ",", "allBumps", ",", 
   "\"\<DXF\>\""}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ExpSet", "[", "frac_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{
       "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
        "<>", "\"\</bumpset_\>\"", "<>", 
        RowBox[{"ToString", "[", "frac", "]"}], "<>", "\"\<.eps\>\""}], ",", 
       RowBox[{"g3dBumpSet", "[", "frac", "]"}], ",", "\"\<EPS\>\""}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{
       "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
        "<>", "\"\</bumpset_\>\"", "<>", 
        RowBox[{"ToString", "[", "frac", "]"}], "<>", "\"\<.svg\>\""}], ",", 
       RowBox[{"g3dBumpSet", "[", "frac", "]"}], ",", "\"\<svg\>\""}], 
      "]"}]}], "}"}]}], "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"ExpSet", "[", "1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ExpSet", "[", ".9", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ExpSet", "[", ".5", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ExpSet", "[", ".25", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ExpSet", "[", ".1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ExpSet", "[", "0", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{
    "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
     "<>", "\"\</bumps.dxf\>\""}], ",", "g3dBumps", ",", "\"\<DXF\>\""}], 
   "]"}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bumpssmat", "[", "i_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"bumpssmat", "[", "i", "]"}], "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MakeBump", "[", "#", "]"}], "&"}], ",", " ", 
       RowBox[{"materialMembers", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", " ", "Full"}], ",", 
     RowBox[{"Lighting", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<Ambient\>\"", ",", " ", "White"}], "}"}], "}"}]}]}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"bumpssmat", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"bumpssmat", "[", "2", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"bumpssmat", "[", "3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"bumpssmat", "[", "4", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
    "<>", "\"\</material_1+bumps.dxf\>\""}], ",", 
   RowBox[{"bumpssmat", "[", "1", "]"}], ",", "\"\<DXF\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
    "<>", "\"\</material_2+bumps.dxf\>\""}], ",", 
   RowBox[{"bumpssmat", "[", "2", "]"}], ",", "\"\<DXF\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
    "<>", "\"\</material_3+bumps.dxf\>\""}], ",", 
   RowBox[{"bumpssmat", "[", "3", "]"}], ",", "\"\<DXF\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
    "<>", "\"\</material_4+bumps.dxf\>\""}], ",", 
   RowBox[{"bumpssmat", "[", "4", "]"}], ",", "\"\<DXF\>\""}], "]"}]], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1202, 743},
WindowMargins->{{9, Automatic}, {Automatic, 20}},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"3016-Carter.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 63, 0, 64, "Title"],
Cell[CellGroupData[{
Cell[678, 27, 33, 0, 34, "Section"],
Cell[714, 29, 83, 2, 37, "Input"],
Cell[800, 33, 83, 2, 37, "Input"],
Cell[886, 37, 76, 1, 37, "Input"],
Cell[965, 40, 87, 1, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1089, 46, 35, 0, 34, "Section"],
Cell[1127, 48, 416, 13, 37, "Input"],
Cell[CellGroupData[{
Cell[1568, 65, 29, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1622, 69, 113, 1, 24, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1738, 72, 320, 8, 37, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[2061, 82, 179, 4, 24, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[2243, 88, 971, 26, 98, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[3217, 116, 157, 3, 24, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[3377, 121, 2616, 69, 218, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[5996, 192, 231, 4, 34, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[6230, 198, 2803, 73, 203, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[9036, 273, 1315, 34, 173, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[10366, 310, 257, 6, 37, "Input"],
Cell[CellGroupData[{
Cell[10648, 320, 114, 3, 24, "Subsubsection"],
Cell[10765, 325, 618, 18, 37, "Input"],
Cell[11386, 345, 782, 28, 53, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12229, 380, 47, 0, 34, "Section"],
Cell[12279, 382, 229, 6, 37, "Input"],
Cell[12511, 390, 300, 7, 37, "Input"],
Cell[12814, 399, 91, 1, 37, "Input"],
Cell[12908, 402, 87, 1, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[13020, 407, 25, 0, 26, "Subsection"],
Cell[13048, 409, 672, 20, 53, "Input"],
Cell[13723, 431, 524, 15, 68, "Input"],
Cell[14250, 448, 817, 25, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15104, 478, 31, 0, 34, "Subsection"],
Cell[15138, 480, 713, 21, 68, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15888, 506, 29, 0, 34, "Subsection"],
Cell[15920, 508, 626, 19, 53, "Input"],
Cell[16549, 529, 605, 19, 37, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17203, 554, 51, 0, 34, "Section"],
Cell[17257, 556, 160, 3, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17454, 564, 52, 0, 44, "Subsubtitle"],
Cell[CellGroupData[{
Cell[17531, 568, 62, 0, 24, "Subsubsection"],
Cell[17596, 570, 253, 6, 53, "Input"],
Cell[17852, 578, 277, 7, 37, "Input"],
Cell[18132, 587, 160, 3, 37, "Input"],
Cell[18295, 592, 33, 0, 26, "Text"],
Cell[18331, 594, 660, 19, 68, "Input"],
Cell[18994, 615, 179, 4, 37, "Input"],
Cell[19176, 621, 33, 0, 26, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19246, 626, 42, 0, 24, "Subsubsection"],
Cell[19291, 628, 328, 11, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19656, 644, 37, 0, 34, "Section"],
Cell[19696, 646, 1759, 50, 53, "Input"],
Cell[21458, 698, 1669, 48, 53, "Input"],
Cell[23130, 748, 1669, 48, 53, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24836, 801, 33, 0, 34, "Section"],
Cell[CellGroupData[{
Cell[24894, 805, 74, 0, 34, "Subsection"],
Cell[24971, 807, 221, 6, 37, "Input"],
Cell[25195, 815, 1098, 36, 83, "Input"],
Cell[26296, 853, 173, 5, 37, "Input"],
Cell[26472, 860, 496, 14, 37, "Input"],
Cell[26971, 876, 82, 2, 37, "Input"],
Cell[27056, 880, 360, 12, 37, "Input"],
Cell[27419, 894, 2582, 75, 98, "Input"],
Cell[30004, 971, 260, 8, 37, "Input"],
Cell[30267, 981, 114, 2, 37, "Input"],
Cell[30384, 985, 224, 6, 37, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30657, 997, 55, 0, 34, "Section"],
Cell[CellGroupData[{
Cell[30737, 1001, 42, 0, 34, "Subsection"],
Cell[30782, 1003, 2504, 69, 83, "Input"],
Cell[33289, 1074, 193, 5, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33519, 1084, 31, 0, 34, "Subsection"],
Cell[33553, 1086, 1323, 34, 68, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34913, 1125, 41, 0, 34, "Subsection"],
Cell[34957, 1127, 1583, 42, 68, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36589, 1175, 32, 0, 34, "Section"],
Cell[CellGroupData[{
Cell[36646, 1179, 37, 0, 34, "Subsection"],
Cell[36686, 1181, 327, 11, 37, "Input"],
Cell[37016, 1194, 458, 13, 37, "Input"],
Cell[37477, 1209, 847, 26, 37, "Input"],
Cell[38327, 1237, 295, 9, 37, "Input"],
Cell[38625, 1248, 174, 5, 37, "Input"],
Cell[38802, 1255, 249, 7, 53, "Input"],
Cell[39054, 1264, 126, 2, 53, "Input"],
Cell[39183, 1268, 117, 2, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39337, 1275, 50, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[39412, 1279, 62, 0, 24, "Subsubsection"],
Cell[39477, 1281, 99, 1, 37, "Input"],
Cell[39579, 1284, 820, 22, 68, "Input"],
Cell[40402, 1308, 298, 10, 37, "Input"],
Cell[40703, 1320, 129, 3, 37, "Input"],
Cell[40835, 1325, 365, 11, 37, "Input"],
Cell[41203, 1338, 344, 11, 37, "Input"],
Cell[41550, 1351, 149, 4, 37, "Input"],
Cell[41702, 1357, 135, 3, 37, "Input"],
Cell[41840, 1362, 381, 12, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42258, 1379, 175, 3, 24, "Subsubsection"],
Cell[42436, 1384, 351, 11, 37, "Input"],
Cell[42790, 1397, 134, 3, 37, "Input"],
Cell[42927, 1402, 379, 12, 37, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[43355, 1420, 93, 2, 34, "Subsection"],
Cell[43451, 1424, 818, 22, 83, "Input"],
Cell[CellGroupData[{
Cell[44294, 1450, 69, 0, 24, "Subsubsection"],
Cell[44366, 1452, 684, 20, 53, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45087, 1477, 52, 0, 24, "Subsubsection"],
Cell[45142, 1479, 521, 12, 53, "Input"],
Cell[45666, 1493, 132, 2, 53, "Input"],
Cell[45801, 1497, 131, 3, 37, "Input"]
}, Open  ]]
}, Open  ]],
Cell[45959, 1504, 52, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[46036, 1508, 180, 4, 26, "Subsection"],
Cell[46219, 1514, 853, 26, 37, "Input"],
Cell[47075, 1542, 95, 2, 37, "Input"],
Cell[47173, 1546, 27, 0, 37, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47249, 1552, 39, 0, 34, "Section"],
Cell[47291, 1554, 718, 21, 68, "Input"],
Cell[48012, 1577, 235, 6, 53, "Input"],
Cell[CellGroupData[{
Cell[48272, 1587, 37, 0, 34, "Subsection"],
Cell[48312, 1589, 2281, 64, 158, "Input"],
Cell[50596, 1655, 26, 0, 37, "Input"],
Cell[50625, 1657, 177, 5, 37, "Input"],
Cell[50805, 1664, 90, 2, 37, "Input"],
Cell[50898, 1668, 257, 8, 37, "Input"],
Cell[51158, 1678, 628, 18, 53, "Input"],
Cell[51789, 1698, 409, 13, 53, "Input"],
Cell[52201, 1713, 86, 2, 37, "Input"],
Cell[52290, 1717, 148, 4, 37, "Input"],
Cell[52441, 1723, 750, 22, 83, "Input"],
Cell[53194, 1747, 98, 2, 37, "Input"],
Cell[53295, 1751, 275, 6, 37, "Input"],
Cell[53573, 1759, 800, 22, 83, "Input"],
Cell[54376, 1783, 476, 13, 53, "Input"],
Cell[54855, 1798, 1652, 46, 113, "Input"],
Cell[56510, 1846, 392, 11, 53, "Input"],
Cell[56905, 1859, 951, 26, 98, "Input"],
Cell[57859, 1887, 302, 9, 37, "Input"],
Cell[58164, 1898, 1172, 28, 143, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59373, 1931, 41, 0, 34, "Subsection"],
Cell[59417, 1933, 434, 13, 37, "Input"],
Cell[59854, 1948, 2636, 76, 218, "Input"],
Cell[62493, 2026, 95, 2, 37, "Input"],
Cell[62591, 2030, 1305, 30, 173, "Input"],
Cell[63899, 2062, 300, 9, 37, "Input"],
Cell[64202, 2073, 26, 0, 37, "Input"],
Cell[64231, 2075, 89, 2, 37, "Input"],
Cell[64323, 2079, 92, 2, 37, "Input"],
Cell[64418, 2083, 2053, 54, 158, "Input"],
Cell[66474, 2139, 290, 9, 37, "Input"],
Cell[66767, 2150, 324, 9, 37, "Input"],
Cell[67094, 2161, 290, 9, 37, "Input"],
Cell[67387, 2172, 702, 20, 53, "Input"],
Cell[68092, 2194, 344, 10, 37, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[68485, 2210, 93, 2, 34, "Section"],
Cell[68581, 2214, 563, 16, 53, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69181, 2235, 39, 0, 34, "Section"],
Cell[69223, 2237, 64, 1, 37, "Input"],
Cell[69290, 2240, 180, 4, 37, "Input"],
Cell[69473, 2246, 478, 12, 37, "Input"],
Cell[69954, 2260, 382, 10, 37, "Input"],
Cell[70339, 2272, 254, 8, 37, "Input"],
Cell[70596, 2282, 230, 6, 37, "Input"],
Cell[70829, 2290, 230, 6, 37, "Input"],
Cell[71062, 2298, 635, 18, 37, "Input"],
Cell[71700, 2318, 64, 1, 37, "Input"],
Cell[71767, 2321, 64, 1, 37, "Input"],
Cell[71834, 2324, 64, 1, 37, "Input"],
Cell[71901, 2327, 64, 1, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72002, 2333, 35, 0, 34, "Section"],
Cell[72040, 2335, 1279, 33, 83, "Input"],
Cell[73322, 2370, 265, 7, 37, "Input"],
Cell[73590, 2379, 265, 7, 37, "Input"],
Cell[73858, 2388, 265, 7, 37, "Input"],
Cell[74126, 2397, 265, 7, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74428, 2409, 88, 1, 34, "Section"],
Cell[74519, 2412, 591, 17, 37, "Input"],
Cell[CellGroupData[{
Cell[75135, 2433, 27, 0, 34, "Subsection"],
Cell[75165, 2435, 884, 24, 113, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76086, 2464, 26, 0, 34, "Subsection"],
Cell[76115, 2466, 1532, 47, 113, "Input"],
Cell[CellGroupData[{
Cell[77672, 2517, 168, 3, 24, "Subsubsection"],
Cell[77843, 2522, 3160, 79, 308, "Input"],
Cell[81006, 2603, 3461, 83, 353, "Input"],
Cell[84470, 2688, 99, 2, 37, "Input"],
Cell[84572, 2692, 532, 13, 37, "Input"],
Cell[85107, 2707, 67, 1, 37, "Input"],
Cell[85177, 2710, 482, 14, 37, "Input"],
Cell[85662, 2726, 63, 1, 37, "Input"],
Cell[85728, 2729, 391, 6, 113, "Input"],
Cell[86122, 2737, 348, 10, 37, "Input"],
Cell[86473, 2749, 493, 12, 53, "Input"],
Cell[86969, 2763, 883, 21, 83, "Input"],
Cell[87855, 2786, 366, 6, 113, "Input"],
Cell[88224, 2794, 258, 7, 37, "Input"],
Cell[88485, 2803, 629, 18, 37, "Input"],
Cell[89117, 2823, 62, 1, 37, "Input"],
Cell[89182, 2826, 62, 1, 37, "Input"],
Cell[89247, 2829, 62, 1, 37, "Input"],
Cell[89312, 2832, 62, 1, 37, "Input"],
Cell[89377, 2835, 266, 6, 37, "Input"],
Cell[89646, 2843, 266, 6, 37, "Input"],
Cell[89915, 2851, 266, 6, 37, "Input"],
Cell[90184, 2859, 266, 6, 37, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
